@@ -40,9 +40,10 @@ def preSymp(string):
         >>> sp.sympify(preSymp('N**2'))
         ... N**2
     """
-    string = string.replace("{", "__0__").replace("}", "__1__")
-    pat = (r"(?!ln|log|sin|cos|tan|exp|atan|sqrt)"
-           r"\\?[a-zA-Z]+[_0-9a-zA-Z({{)(}}),]*")
+    string = string.replace("{", "__0__").replace("}", "__1__")\
+                   .replace('np.', '')
+    pat = (r"\\?\b(?!ln|log|sin|cos|tan|exp|atan|sqrt)"
+           r"[a-zA-Z]+[_0-9a-zA-Z({{)(}}),]*\b")
     a = [f"Symbol('{i}')" for i in re.findall(pat, string)]
     return re.sub(pat, r"{}", string).format(*a).replace("__0__", "{")\
                                                 .replace("__1__", "}")
@@ -124,3 +125,39 @@ def rejectOutliers(data, n=2):
 
 def roll(values, min, max):
     return ((values-min) % (max-min))+min
+
+
+def lock_axes(ax):
+    ax.set_xlim(ax.get_xlim())
+    ax.set_ylim(ax.get_ylim())
+
+def precisionStr(x, delt):
+    """
+    returns a string representing a number with specified amount of significant values
+
+    (x) the number you want to be represented correctly
+
+    """
+    sig = ''
+    if np.sign(x) == -1:
+        sig = '-'
+        x = abs(x)
+    if x == 0:
+        n = -int(np.floor(np.log10(delt)))+1
+        o = 0
+    else:
+        n = int(np.floor(np.log10(x)))-int(np.floor(np.log10(delt)))+1
+        o = int(np.log10(x))
+
+    s = str(x*10**-o).replace('.', '')[:n+1]
+    l = len(s)
+    s += '0'*(n-l)
+    s += '0'*-(l-o-1)
+    s = '0'*-o + s
+    if o > 0:
+        s = s[:o+1] + '.' + s[o+1:]
+    else:
+        s = s[0] + '.' + s[1:]
+    if s[-1] == '.':
+        s = s[:-1]
+    return sig+s
\ No newline at end of file
